<?php

namespace App\Community\Controllers;

use App\Models\OrderVaccine;
use Encore\Admin\Controllers\AdminController;
use Encore\Admin\Form;
use Encore\Admin\Grid;
use Encore\Admin\Show;

class OrderVaccinesController extends AdminController
{
    /**
     * Title for current resource.
     *
     * @var string
     */
    protected $title = '计免预约';

    /**
     * Make a grid builder.
     *
     * @return Grid
     */
    protected function grid()
    {
        $grid = new Grid(new OrderVaccine());

        $grid->column('id', __('Id'));
        $grid->column('patients.name', __('预约用户'));
        $grid->column('vaccine_id', __('预约时间'));
        $grid->column('vaccine_type', __('接种时间'));
        $grid->column('patients.name', __('接种患者'));
        $grid->column('patients.sex', __('患者性别'))->display(function ($w){
            return $w==1?'男':'女';
        });
        $grid->column('patients.birthday', __('患者年龄'))->display(function ($w){
            return birthday_to_age($w);
        });
        $grid->column('vaccine_name', __('接种疫苗'));
        $grid->column('docters.name', __('排班医生'));
        $grid->column('orders.order_status', __('订单状态'))->using([1=>'未支付',2=>'待接单',3=>'进行中',4=>'已完成',5=>'已取消']);
        $grid->column('orders.payment_status', __('支付状态'))->using([1=>'待付款',2=>'已付款',3=>'退款中',4=>'已退款']);

        return $grid;
    }

    /**
     * Make a show builder.
     *
     * @param mixed $id
     * @return Show
     */
    protected function detail($id)
    {
        $show = new Show(OrderVaccine::findOrFail($id));

        $show->field('id', __('Id'));
        $show->field('order_id', __('Order id'));
        $show->field('order_patient_id', __('Order patient id'));
        $show->field('vaccine_id', __('Vaccine id'));
        $show->field('vaccine_type', __('Vaccine type'));
        $show->field('vaccine_price', __('Vaccine price'));
        $show->field('vaccine_name', __('Vaccine name'));
        $show->field('vaccine_remark', __('Vaccine remark'));
        $show->field('vaccine_supplier', __('Vaccine supplier'));
        $show->field('created_at', __('Created at'));
        $show->field('updated_at', __('Updated at'));

        return $show;
    }

    /**
     * Make a form builder.
     *
     * @return Form
     */
    protected function form()
    {
        $form = new Form(new OrderVaccine());

        $form->number('order_id', __('Order id'));
        $form->number('order_patient_id', __('Order patient id'));
        $form->number('vaccine_id', __('Vaccine id'));
        $form->switch('vaccine_type', __('Vaccine type'));
        $form->number('vaccine_price', __('Vaccine price'));
        $form->text('vaccine_name', __('Vaccine name'));
        $form->text('vaccine_remark', __('Vaccine remark'));
        $form->text('vaccine_supplier', __('Vaccine supplier'));

        return $form;
    }
}
